@@ -20,6 +20,11 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     Calculates the Minkowski deviation of
     order p. When the order = 2, it is the
     same as the standard deviation.
+
+    Parameters
+    ----------
+    x : array-like.
+
     '''
     result = x - np.mean(x)
     result = np.abs(x)
@@ -30,23 +35,23 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
 
 def reflective_correlation(X: np.ndarray) -> np.float64:
     '''
-    Calculates the n-ary reflective correlation coefficient.
+    Calculates the multilinear reflective correlation coefficient.
     When given an m x 2 data matrix, it is equivalent to the
     reflective correlation coefficient.
 
     Parameters
     ----------
-        X : array_like
-            The m x n data matrix.
+    X : array_like
+        The m x n data matrix.
 
     Returns
     -------
     r : float
-        The calculated reflective correlation coefficient.
+        Reflective correlation coefficient score.
 
     References
     ----------
-    .. [1] https://en.wikipedia.org/wiki/Pearson_correlation_coefficient#Reflective_correlation_coefficient
+    .. [1] "Reflective Correlation Coefficient.", https://en.wikipedia.org/wiki/Pearson_correlation_coefficient#Reflective_correlation_coefficient
 
     Examples
     ----------
@@ -69,7 +74,7 @@ def pearson_correlation(X: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-        X : array_like
+        X : array-like
             The m x n data matrix.
 
     Returns
@@ -263,11 +268,22 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
 
 def taylor_correlation(X: np.ndarray) -> np.float64:
     '''
-    Taylor 2020 correlation
+    Taylor's multi-way correlation coefficient.
 
     References
     ----------
     .. [1] Taylor, BM. 2020. "A Multi-Way Correlation Coefficient", https://arxiv.org/abs/2003.02561
+
+    Notes
+    -----
+    Taylor 2020 defines this function to be
+
+    .. math:: \frac{1}{\sqrt{d}} \sqrt{\frac{1}{d-1} \sum_{i}^{d} ( \lambda_i \bar{\lambda})^2 }
+
+    where :math:`d` is the number of variables, :math:`\lambda_1, \cdots, \lambda_d` are the eigenvalues of
+    the correlation matrix for a given set of variables, and :math:`\bar{\lambda}` is the mean of those eigenvalue.
+    Thus Taylor's multi-way correlation coefficient is a rescaling of the Bessel-corrected standard deviation of the
+    eigenvalues of the correlation matrix of the set of variables.
     '''
     d = X.shape[1]
     result = np.corrcoef(X)
